@@ -1,3 +1,8 @@
+// Copyright 2017 The Emscripten Authors.  All rights reserved.
+// Emscripten is available under two separate licenses, the MIT license and the
+// University of Illinois/NCSA Open Source License.  Both these licenses can be
+// found in the LICENSE file.
+
 // {{PREAMBLE_ADDITIONS}}
 
 var STACK_ALIGN = {{{ STACK_ALIGN }}};
@@ -308,6 +313,7 @@ Module['loadWebAssemblyModule'] = loadWebAssemblyModule;
 #endif // RELOCATABLE
 
 #if EMULATED_FUNCTION_POINTERS
+#if WASM == 0
 function getFunctionTables(module) {
   if (!module) module = Module;
   var tables = {};
@@ -333,6 +339,7 @@ function alignFunctionTables(module) {
   }
   return maxx;
 }
+#endif // WASM == 0
 
 #if RELOCATABLE
 // register functions from a new module being loaded
