@@ -1,3 +1,8 @@
+# Copyright 2012 The Emscripten Authors.  All rights reserved.
+# Emscripten is available under two separate licenses, the MIT license and the
+# University of Illinois/NCSA Open Source License.  Both these licenses can be
+# found in the LICENSE file.
+
 '''
 A tool that generates FS API calls to generate a filesystem, and packages the files
 to work with that.
@@ -16,7 +21,7 @@ data downloads.
 
 Usage:
 
-  file_packager.py TARGET [--preload A [B..]] [--embed C [D..]] [--exclude E [F..]] [--crunch[=X]] [--js-output=OUTPUT.js] [--no-force] [--use-preload-cache] [--indexedDB-name=EM_PRELOAD_CACHE] [--no-heap-copy] [--separate-metadata] [--lz4] [--use-preload-plugins]
+  file_packager.py TARGET [--preload A [B..]] [--embed C [D..]] [--exclude E [F..]]] [--js-output=OUTPUT.js] [--no-force] [--use-preload-cache] [--indexedDB-name=EM_PRELOAD_CACHE] [--no-heap-copy] [--separate-metadata] [--lz4] [--use-preload-plugins]
 
   --preload  ,
   --embed    See emcc --help for more details on those options.
@@ -26,14 +31,6 @@ Usage:
 
   --from-emcc Indicate that `file_packager.py` was called from `emcc.py` and will be further processed by it, so some code generation can be skipped here
 
-  --crunch=X Will compress dxt files to crn with quality level X. The crunch commandline tool must be present
-             and CRUNCH should be defined in ~/.emscripten that points to it. JS crunch decompressing code will
-             be added to convert the crn to dds in the browser.
-             crunch-worker.js will be generated in the current directory. You should include that file when
-             packaging your site.
-             DDS files will not be crunched if the .crn is more recent than the .dds. This prevents a lot of
-             unneeded computation.
-
   --js-output=FILE Writes output in FILE, if not specified, standard output is used.
 
   --export-name=EXPORT_NAME Use custom export name (default is `Module`)
@@ -60,13 +57,15 @@ Notes:
 
   * The file packager generates unix-style file paths. So if you are on windows and a file is accessed at
     subdir\file, in JS it will be subdir/file. For simplicity we treat the web platform as a *NIX.
-
-TODO:        You can also provide .crn files yourself, pre-crunched. With this option, they will be decompressed
-             to dds files in the browser, exactly the same as if this tool compressed them.
 '''
 
 from __future__ import print_function
-import os, sys, shutil, random, uuid, ctypes
+import os
+import sys
+import shutil
+import random
+import uuid
+import ctypes
 
 sys.path.insert(1, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
@@ -76,14 +75,13 @@ if __name__ == '__main__':
 
 import posixpath
 from tools import shared
-from tools.shared import execute, suffix, unsuffixed
 from tools.jsrun import run_js
-from subprocess import Popen, PIPE, STDOUT
+from subprocess import PIPE
 import fnmatch
 import json
 
 if len(sys.argv) == 1:
-  print('''Usage: file_packager.py TARGET [--preload A...] [--embed B...] [--exclude C...] [--no-closure] [--crunch[=X]] [--js-output=OUTPUT.js] [--no-force] [--use-preload-cache] [--no-heap-copy] [--separate-metadata]
+  print('''Usage: file_packager.py TARGET [--preload A...] [--embed B...] [--exclude C...] [--no-closure]] [--js-output=OUTPUT.js] [--no-force] [--use-preload-cache] [--no-heap-copy] [--separate-metadata]
 See the source for more details.''')
   sys.exit(0)
 
@@ -93,13 +91,13 @@ data_target = sys.argv[1]
 
 IMAGE_SUFFIXES = ('.jpg', '.png', '.bmp')
 AUDIO_SUFFIXES = ('.ogg', '.wav', '.mp3')
-AUDIO_MIMETYPES = { 'ogg': 'audio/ogg', 'wav': 'audio/wav', 'mp3': 'audio/mpeg' }
-CRUNCH_INPUT_SUFFIX = '.dds'
-CRUNCH_OUTPUT_SUFFIX = '.crn'
+AUDIO_MIMETYPES = {'ogg': 'audio/ogg', 'wav': 'audio/wav', 'mp3': 'audio/mpeg'}
 
 DDS_HEADER_SIZE = 128
 
-AV_WORKAROUND = 0 # Set to 1 to randomize file order and add some padding, to work around silly av false positives
+# Set to 1 to randomize file order and add some padding,
+# to work around silly av false positives
+AV_WORKAROUND = 0
 
 data_files = []
 excluded_patterns = []
@@ -107,21 +105,26 @@ export_name = 'Module'
 leading = ''
 has_preloaded = False
 compress_cnt = 0
-crunch = 0
 plugins = []
 jsoutput = None
 from_emcc = False
 force = True
-# If set to True, IndexedDB (IDBFS in library_idbfs.js) is used to locally cache VFS XHR so that subsequent
-# page loads can read the data from the offline cache instead.
+# If set to True, IndexedDB (IDBFS in library_idbfs.js) is used to locally
+# cache VFS XHR so that subsequent page loads can read the data from the
+# offline cache instead.
 use_preload_cache = False
 indexeddb_name = 'EM_PRELOAD_CACHE'
-# If set to True, the blob received from XHR is moved to the Emscripten HEAP, optimizing for mmap() performance.
-# If set to False, the XHR blob is kept intact, and fread()s etc. are performed directly to that data. This optimizes for minimal memory usage and fread() performance.
+# If set to True, the blob received from XHR is moved to the Emscripten HEAP,
+# optimizing for mmap() performance.
+# If set to False, the XHR blob is kept intact, and fread()s etc. are performed
+# directly to that data. This optimizes for minimal memory usage and fread()
+# performance.
 no_heap_copy = True
-# If set to True, the package metadata is stored separately from js-output file which makes js-output file immutable to the package content changes.
-# If set to False, the package metadata is stored inside the js-output file which makes js-output file to mutate on each invocation of this packager tool.
-separate_metadata  = False
+# If set to True, the package metadata is stored separately from js-output
+# file which makes js-output file immutable to the package content changes.
+# If set to False, the package metadata is stored inside the js-output file
+# which makes js-output file to mutate on each invocation of this packager tool.
+separate_metadata = False
 lz4 = False
 use_preload_plugins = False
 
@@ -164,30 +167,28 @@ for arg in sys.argv[2:]:
   elif arg.startswith('--from-emcc'):
     from_emcc = True
     leading = ''
-  elif arg.startswith('--crunch'):
-    try:
-      from tools.shared import CRUNCH
-    except Exception as e:
-      print('could not import CRUNCH (make sure it is defined properly in ' + shared.hint_config_file_location() + ')', file=sys.stderr)
-      raise e
-    crunch = arg.split('=', 1)[1] if '=' in arg else '128'
-    leading = ''
   elif arg.startswith('--plugin'):
     plugin = open(arg.split('=', 1)[1], 'r').read()
     eval(plugin) # should append itself to plugins
     leading = ''
   elif leading == 'preload' or leading == 'embed':
     mode = leading
-    at_position = arg.replace('@@', '__').find('@') # position of @ if we're doing 'src@dst'. '__' is used to keep the index same with the original if they escaped with '@@'.
-    uses_at_notation = (at_position != -1) # '@@' in input string means there is an actual @ character, a single '@' means the 'src@dst' notation.
+    # position of @ if we're doing 'src@dst'. '__' is used to keep the index
+    # same with the original if they escaped with '@@'.
+    at_position = arg.replace('@@', '__').find('@')
+    # '@@' in input string means there is an actual @ character, a single '@'
+    # means the 'src@dst' notation.
+    uses_at_notation = (at_position != -1)
 
     if uses_at_notation:
       srcpath = arg[0:at_position].replace('@@', '@') # split around the @
-      dstpath = arg[at_position+1:].replace('@@', '@')
+      dstpath = arg[at_position + 1:].replace('@@', '@')
     else:
-      srcpath = dstpath = arg.replace('@@', '@') # Use source path as destination path.
+      # Use source path as destination path.
+      srcpath = dstpath = arg.replace('@@', '@')
     if os.path.isfile(srcpath) or os.path.isdir(srcpath):
-      data_files.append({ 'srcpath': srcpath, 'dstpath': dstpath, 'mode': mode, 'explicit_dst_path': uses_at_notation })
+      data_files.append({'srcpath': srcpath, 'dstpath': dstpath, 'mode': mode,
+                         'explicit_dst_path': uses_at_notation})
     else:
       print('Warning: ' + arg + ' does not exist, ignoring.', file=sys.stderr)
   elif leading == 'exclude':
@@ -198,14 +199,19 @@ for arg in sys.argv[2:]:
 
 if (not force) and len(data_files) == 0:
   has_preloaded = False
-if not has_preloaded or jsoutput == None:
-  assert not separate_metadata, 'cannot separate-metadata without both --preloaded files and a specified --js-output'
+if not has_preloaded or jsoutput is None:
+  assert not separate_metadata, (
+     'cannot separate-metadata without both --preloaded files '
+     'and a specified --js-output')
 
 if not from_emcc:
-  print('Remember to build the main file with  -s FORCE_FILESYSTEM=1  so that it includes support for loading this file package', file=sys.stderr)
+  print('Remember to build the main file with  -s FORCE_FILESYSTEM=1  '
+        'so that it includes support for loading this file package',
+        file=sys.stderr)
 
 ret = ''
-# emcc.py will add this to the output itself, so it is only needed for standalone calls
+# emcc.py will add this to the output itself, so it is only needed for
+# standalone calls
 if not from_emcc:
   ret = '''
 var Module = typeof %(EXPORT_NAME)s !== 'undefined' ? %(EXPORT_NAME)s : {};
@@ -227,22 +233,26 @@ code = '''
     }
 '''
 
-# Win32 code to test whether the given file has the hidden property set.
+
 def has_hidden_attribute(filepath):
+  """Win32 code to test whether the given file has the hidden property set."""
+
   if sys.platform != 'win32':
     return False
 
   try:
-    attrs = ctypes.windll.kernel32.GetFileAttributesW(unicode(filepath))
+    attrs = ctypes.windll.kernel32.GetFileAttributesW(
+        u'%s' % filepath)
     assert attrs != -1
     result = bool(attrs & 2)
-  except:
+  except Exception:
     result = False
   return result
 
-# The packager should never preload/embed files if the file is hidden (Win32).
-# or it matches any pattern specified in --exclude
+
 def should_ignore(fullname):
+  """The packager should never preload/embed files if the file
+  is hidden (Win32) or it matches any pattern specified in --exclude"""
   if has_hidden_attribute(fullname):
     return True
 
@@ -251,10 +261,15 @@ def should_ignore(fullname):
       return True
   return False
 
-# Expand directories into individual files
+
 def add(mode, rootpathsrc, rootpathdst):
-  # rootpathsrc: The path name of the root directory on the local FS we are adding to emscripten virtual FS.
-  # rootpathdst: The name we want to make the source path available on the emscripten virtual FS.
+  """Expand directories into individual files
+
+  rootpathsrc: The path name of the root directory on the local FS we are
+               adding to emscripten virtual FS.
+  rootpathdst: The name we want to make the source path available on the
+               emscripten virtual FS.
+  """
   for dirpath, dirnames, filenames in os.walk(rootpathsrc):
     new_dirnames = []
     for name in dirnames:
@@ -262,17 +277,23 @@ def add(mode, rootpathsrc, rootpathdst):
       if not should_ignore(fullname):
         new_dirnames.append(name)
       elif DEBUG:
-        print('Skipping directory "' + fullname + '" from inclusion in the emscripten virtual file system.', file=sys.stderr)
+        print('Skipping directory "%s" from inclusion in the emscripten '
+              'virtual file system.' % fullname, file=sys.stderr)
     for name in filenames:
       fullname = os.path.join(dirpath, name)
       if not should_ignore(fullname):
-        dstpath = os.path.join(rootpathdst, os.path.relpath(fullname, rootpathsrc)) # Convert source filename relative to root directory of target FS.
-        new_data_files.append({ 'srcpath': fullname, 'dstpath': dstpath, 'mode': mode, 'explicit_dst_path': True })
+        # Convert source filename relative to root directory of target FS.
+        dstpath = os.path.join(rootpathdst,
+                               os.path.relpath(fullname, rootpathsrc))
+        new_data_files.append({'srcpath': fullname, 'dstpath': dstpath,
+                               'mode': mode, 'explicit_dst_path': True})
       elif DEBUG:
-        print('Skipping file "' + fullname + '" from inclusion in the emscripten virtual file system.', file=sys.stderr)
+        print('Skipping file "%s" from inclusion in the emscripten '
+              'virtual file system.' % fullname, file=sys.stderr)
     del dirnames[:]
     dirnames.extend(new_dirnames)
 
+
 new_data_files = []
 for file_ in data_files:
   if not should_ignore(file_['srcpath']):
@@ -280,43 +301,67 @@ for file_ in data_files:
       add(file_['mode'], file_['srcpath'], file_['dstpath'])
     else:
       new_data_files.append(file_)
-data_files = [file_ for file_ in new_data_files if not os.path.isdir(file_['srcpath'])]
+data_files = [file_ for file_ in new_data_files
+              if not os.path.isdir(file_['srcpath'])]
 if len(data_files) == 0:
   print('Nothing to do!', file=sys.stderr)
   sys.exit(1)
 
 # Absolutize paths, and check that they make sense
-curr_abspath = os.path.abspath(os.getcwd()) # os.getcwd() always returns the hard path with any symbolic links resolved, even if we cd'd into a symbolic link.
+# os.getcwd() always returns the hard path with any symbolic links resolved,
+# even if we cd'd into a symbolic link.
+curr_abspath = os.path.abspath(os.getcwd())
 
 for file_ in data_files:
   if not file_['explicit_dst_path']:
-    # This file was not defined with src@dst, so we inferred the destination from the source. In that case,
-    # we require that the destination not be under the current location
+    # This file was not defined with src@dst, so we inferred the destination
+    # from the source. In that case, we require that the destination not be
+    # under the current location
     path = file_['dstpath']
-    abspath = os.path.realpath(os.path.abspath(path)) # Use os.path.realpath to resolve any symbolic links to hard paths, to match the structure in curr_abspath.
-    if DEBUG: print(path, abspath, curr_abspath, file=sys.stderr)
+    # Use os.path.realpath to resolve any symbolic links to hard paths,
+    # to match the structure in curr_abspath.
+    abspath = os.path.realpath(os.path.abspath(path))
+    if DEBUG:
+        print(path, abspath, curr_abspath, file=sys.stderr)
     if not abspath.startswith(curr_abspath):
-      print('Error: Embedding "%s" which is below the current directory "%s". This is invalid since the current directory becomes the root that the generated code will see' % (path, curr_abspath), file=sys.stderr)
+      print('Error: Embedding "%s" which is below the current directory '
+            '"%s". This is invalid since the current directory becomes the '
+            'root that the generated code will see' % (path, curr_abspath),
+            file=sys.stderr)
       sys.exit(1)
-    file_['dstpath'] = abspath[len(curr_abspath)+1:]
+    file_['dstpath'] = abspath[len(curr_abspath) + 1:]
     if os.path.isabs(path):
-      print('Warning: Embedding an absolute file/directory name "' + path + '" to the virtual filesystem. The file will be made available in the relative path "' + file_['dstpath'] + '". You can use the explicit syntax --preload-file srcpath@dstpath to explicitly specify the target location the absolute source path should be directed to.', file=sys.stderr)
+      print('Warning: Embedding an absolute file/directory name "%s" to the '
+            'virtual filesystem. The file will be made available in the '
+            'relative path "%s". You can use the explicit syntax '
+            '--preload-file srcpath@dstpath to explicitly specify the target '
+            'location the absolute source path should be directed to.'
+            % (path, file_['dstpath']), file=sys.stderr)
 
 for file_ in data_files:
-  file_['dstpath'] = file_['dstpath'].replace(os.path.sep, '/') # name in the filesystem, native and emulated
-  if file_['dstpath'].endswith('/'): # If user has submitted a directory name as the destination but omitted the destination filename, use the filename from source file
+  # name in the filesystem, native and emulated
+  file_['dstpath'] = file_['dstpath'].replace(os.path.sep, '/')
+  # If user has submitted a directory name as the destination but omitted
+  # the destination filename, use the filename from source file
+  if file_['dstpath'].endswith('/'):
     file_['dstpath'] = file_['dstpath'] + os.path.basename(file_['srcpath'])
   # make destination path always relative to the root
   file_['dstpath'] = posixpath.normpath(os.path.join('/', file_['dstpath']))
   if DEBUG:
-    print('Packaging file "' + file_['srcpath'] + '" to VFS in path "' + file_['dstpath'] + '".', file=sys.stderr)
+    print('Packaging file "%s" to VFS in path "%s".'
+          % (file_['srcpath'],  file_['dstpath']), file=sys.stderr)
 
 # Remove duplicates (can occur naively, for example preload dir/, preload dir/subdir/)
 seen = {}
+
+
 def was_seen(name):
-  if seen.get(name): return True
+  if seen.get(name):
+      return True
   seen[name] = 1
   return False
+
+
 data_files = [file_ for file_ in data_files if not was_seen(file_['dstpath'])]
 
 if AV_WORKAROUND:
@@ -329,66 +374,6 @@ for file_ in data_files:
 
 metadata = {'files': []}
 
-# Crunch files
-if crunch:
-  shutil.copyfile(shared.path_from_root('tools', 'crunch-worker.js'), 'crunch-worker.js')
-  ret += '''
-    var decrunchWorker = new Worker('crunch-worker.js');
-    var decrunchCallbacks = [];
-    decrunchWorker.onmessage = function(msg) {
-      decrunchCallbacks[msg.data.callbackID](msg.data.data);
-      console.log('decrunched ' + msg.data.filename + ' in ' + msg.data.time + ' ms, ' + msg.data.data.length + ' bytes');
-      decrunchCallbacks[msg.data.callbackID] = null;
-    };
-    function requestDecrunch(filename, data, callback) {
-      decrunchWorker.postMessage({
-        filename: filename,
-        data: new Uint8Array(data),
-        callbackID: decrunchCallbacks.length
-      });
-      decrunchCallbacks.push(callback);
-    }
-'''
-
-  for file_ in data_files:
-    if file_['dstpath'].endswith(CRUNCH_INPUT_SUFFIX):
-      src_dds_name = file_['srcpath']
-      src_crunch_name = unsuffixed(src_dds_name) + CRUNCH_OUTPUT_SUFFIX
-
-      # Preload/embed the .crn version instead of the .dds version, but use the .dds suffix for the target file in the virtual FS.
-      file_['srcpath'] = src_crunch_name
-
-      try:
-        # Do not crunch if crunched version exists and is more recent than dds source
-        crunch_time = os.stat(src_crunch_name).st_mtime
-        dds_time = os.stat(src_dds_name).st_mtime
-        if dds_time < crunch_time: continue
-      except:
-        pass # if one of them does not exist, continue on
-
-      # guess at format. this lets us tell crunch to not try to be clever and use odd formats like DXT5_AGBR
-      try:
-        format = run_process(['file', file_['srcpath']], stdout=PIPE).stdout
-        if 'DXT5' in format:
-          format = ['-dxt5']
-        elif 'DXT1' in format:
-          format = ['-dxt1']
-        else:
-          raise Exception('unknown format')
-      except:
-        format = []
-      Popen([CRUNCH, '-outsamedir', '-file', src_dds_name, '-quality', crunch] + format, stdout=sys.stderr).communicate()
-      #if not os.path.exists(os.path.basename(crunch_name)):
-      #  print >> sys.stderr, 'Failed to crunch, perhaps a weird dxt format? Looking for a source PNG for the DDS'
-      #  Popen([CRUNCH, '-file', unsuffixed(file_['srcpath']) + '.png', '-quality', crunch] + format, stdout=sys.stderr).communicate()
-      assert os.path.exists(src_crunch_name), 'crunch failed to generate output'
-      # prepend the dds header
-      crunched = open(src_crunch_name, 'rb').read()
-      c = open(src_crunch_name, 'wb')
-      c.write(open(src_dds_name, 'rb').read()[:DDS_HEADER_SIZE])
-      c.write(crunched)
-      c.close()
-
 # Set up folders
 partial_dirs = []
 for file_ in data_files:
@@ -397,27 +382,32 @@ for file_ in data_files:
   if dirname != '':
     parts = dirname.split('/')
     for i in range(len(parts)):
-      partial = '/'.join(parts[:i+1])
+      partial = '/'.join(parts[:i + 1])
       if partial not in partial_dirs:
-        code += '''Module['FS_createPath']('/%s', '%s', true, true);\n''' % ('/'.join(parts[:i]), parts[i])
+        code += ('''Module['FS_createPath']('/%s', '%s', true, true);\n'''
+                 % ('/'.join(parts[:i]), parts[i]))
         partial_dirs.append(partial)
 
 if has_preloaded:
-  # Bundle all datafiles into one archive. Avoids doing lots of simultaneous XHRs which has overhead.
+  # Bundle all datafiles into one archive. Avoids doing lots of simultaneous
+  # XHRs which has overhead.
   data = open(data_target, 'wb')
   start = 0
   for file_ in data_files:
     file_['data_start'] = start
     curr = open(file_['srcpath'], 'rb').read()
     file_['data_end'] = start + len(curr)
-    if AV_WORKAROUND: curr += '\x00'
-    #print >> sys.stderr, 'bundling', file_['srcpath'], file_['dstpath'], file_['data_start'], file_['data_end']
+    if AV_WORKAROUND:
+        curr += '\x00'
     start += len(curr)
     data.write(curr)
   data.close()
   # TODO: sha256sum on data_target
-  if start > 256*1024*1024:
-    print('warning: file packager is creating an asset bundle of %d MB. this is very large, and browsers might have trouble loading it. see https://hacks.mozilla.org/2015/02/synchronous-execution-and-filesystem-access-in-emscripten/' % (start/(1024*1024)), file=sys.stderr)
+  if start > 256 * 1024 * 1024:
+    print('warning: file packager is creating an asset bundle of %d MB. '
+          'this is very large, and browsers might have trouble loading it. '
+          'see https://hacks.mozilla.org/2015/02/synchronous-execution-and-filesystem-access-in-emscripten/'
+          % (start / (1024 * 1024)), file=sys.stderr)
 
   create_preloaded = '''
         Module['FS_createPreloadedFile'](this.name, null, byteArray, true, true, function() {
@@ -426,7 +416,7 @@ if has_preloaded:
           if (that.audio) {
             Module['removeRunDependency']('fp ' + that.name); // workaround for chromium bug 124926 (still no audio with this, but at least we don't hang)
           } else {
-            Module.printErr('Preloading file ' + that.name + ' failed');
+            err('Preloading file ' + that.name + ' failed');
           }
         }, false, true); // canOwn this data in the filesystem, it is a slide into the heap that will never change
 '''
@@ -435,12 +425,12 @@ if has_preloaded:
         Module['removeRunDependency']('fp ' + that.name);
 '''
 
-  # Data requests - for getting a block of data out of the big archive - have a similar API to XHRs
+  # Data requests - for getting a block of data out of the big archive - have
+  # a similar API to XHRs
   code += '''
-    function DataRequest(start, end, crunched, audio) {
+    function DataRequest(start, end, audio) {
       this.start = start;
       this.end = end;
-      this.crunched = crunched;
       this.audio = audio;
     }
     DataRequest.prototype = {
@@ -453,9 +443,7 @@ if has_preloaded:
       send: function() {},
       onload: function() {
         var byteArray = this.byteArray.subarray(this.start, this.end);
-%s
-          this.finish(byteArray);
-%s
+        this.finish(byteArray);
       },
       finish: function(byteArray) {
         var that = this;
@@ -464,23 +452,10 @@ if has_preloaded:
       }
     };
 %s
-  ''' % ('' if not crunch else '''
-        if (this.crunched) {
-          var ddsHeader = byteArray.subarray(0, 128);
-          var that = this;
-          requestDecrunch(this.name, byteArray.subarray(128), function(ddsData) {
-            byteArray = new Uint8Array(ddsHeader.length + ddsData.length);
-            byteArray.set(ddsHeader, 0);
-            byteArray.set(ddsData, 128);
-            that.finish(byteArray);
-          });
-        } else {
-''', '' if not crunch else '''
-        }
-''', create_preloaded if use_preload_plugins else create_data, '''
+  ''' % (create_preloaded if use_preload_plugins else create_data, '''
         var files = metadata.files;
         for (var i = 0; i < files.length; ++i) {
-          new DataRequest(files[i].start, files[i].end, files[i].crunched, files[i].audio).open('GET', files[i].filename);
+          new DataRequest(files[i].start, files[i].end, files[i].audio).open('GET', files[i].filename);
         }
 ''' if not lz4 else '')
 
@@ -498,10 +473,12 @@ for file_ in data_files:
       chunk_size = 10240
       start = 0
       while start < len(data):
-        parts.append('''fileData%d.push.apply(fileData%d, %s);\n''' % (counter, counter, str(data[start:start+chunk_size])))
+        parts.append('''fileData%d.push.apply(fileData%d, %s);\n'''
+                     % (counter, counter, str(data[start:start + chunk_size])))
         start += chunk_size
       code += ''.join(parts)
-    code += '''Module['FS_createDataFile']('%s', '%s', fileData%d, true, true, false);\n''' % (dirname, basename, counter)
+    code += ('''Module['FS_createDataFile']('%s', '%s', fileData%d, true, true, false);\n'''
+             % (dirname, basename, counter))
     counter += 1
   elif file_['mode'] == 'preload':
     # Preload
@@ -511,7 +488,6 @@ for file_ in data_files:
       'filename': file_['dstpath'],
       'start': file_['data_start'],
       'end': file_['data_end'],
-      'crunched': 1 if crunch and filename.endswith(CRUNCH_INPUT_SUFFIX) else 0,
       'audio': 1 if filename[-4:] in AUDIO_SUFFIXES else 0,
     })
   else:
@@ -524,7 +500,7 @@ if has_preloaded:
       use_data = '''
         // copy the entire loaded file into a spot in the heap. Files will refer to slices in that. They cannot be freed though
         // (we may be allocating before malloc is ready, during startup).
-        if (Module['SPLIT_MEMORY']) Module.printErr('warning: you should run the file packager with --no-heap-copy when SPLIT_MEMORY is used, otherwise copying into the heap may fail due to the splitting');
+        if (Module['SPLIT_MEMORY']) err('warning: you should run the file packager with --no-heap-copy when SPLIT_MEMORY is used, otherwise copying into the heap may fail due to the splitting');
         var ptr = Module['getMemory'](byteArray.length);
         Module['HEAPU8'].set(byteArray, ptr);
         DataRequest.prototype.byteArray = Module['HEAPU8'].subarray(ptr, ptr+byteArray.length);
@@ -540,13 +516,17 @@ if has_preloaded:
             DataRequest.prototype.requests[files[i].filename].onload();
           }
     '''
-    use_data += "          Module['removeRunDependency']('datafile_%s');\n" % shared.JS.escape_for_js_string(data_target)
+    use_data += ("          Module['removeRunDependency']('datafile_%s');\n"
+                 % shared.JS.escape_for_js_string(data_target))
 
   else:
     # LZ4FS usage
     temp = data_target + '.orig'
     shutil.move(data_target, temp)
-    meta = run_js(shared.path_from_root('tools', 'lz4-compress.js'), shared.NODE_JS, [shared.path_from_root('src', 'mini-lz4.js'), temp, data_target], stdout=PIPE)
+    meta = run_js(shared.path_from_root('tools', 'lz4-compress.js'),
+                  shared.NODE_JS,
+                  [shared.path_from_root('src', 'mini-lz4.js'),
+                   temp, data_target], stdout=PIPE)
     os.unlink(temp)
     use_data = '''
           var compressedData = %s;
@@ -556,7 +536,7 @@ if has_preloaded:
           Module['removeRunDependency']('datafile_%s');
     ''' % (meta, shared.JS.escape_for_js_string(data_target))
 
-  package_uuid = uuid.uuid4();
+  package_uuid = uuid.uuid4()
   package_name = data_target
   statinfo = os.stat(package_name)
   remote_package_size = statinfo.st_size
@@ -575,12 +555,11 @@ if has_preloaded:
     var REMOTE_PACKAGE_BASE = '%s';
     if (typeof Module['locateFilePackage'] === 'function' && !Module['locateFile']) {
       Module['locateFile'] = Module['locateFilePackage'];
-      Module.printErr('warning: you defined Module.locateFilePackage, that has been renamed to Module.locateFile (using your locateFilePackage for now)');
+      err('warning: you defined Module.locateFilePackage, that has been renamed to Module.locateFile (using your locateFilePackage for now)');
     }
-    var REMOTE_PACKAGE_NAME = typeof Module['locateFile'] === 'function' ?
-                              Module['locateFile'](REMOTE_PACKAGE_BASE) :
-                              ((Module['filePackagePrefixURL'] || '') + REMOTE_PACKAGE_BASE);
-  ''' % (shared.JS.escape_for_js_string(data_target), shared.JS.escape_for_js_string(remote_package_name))
+    var REMOTE_PACKAGE_NAME = Module['locateFile'] ? Module['locateFile'](REMOTE_PACKAGE_BASE, '') : REMOTE_PACKAGE_BASE;
+  ''' % (shared.JS.escape_for_js_string(data_target),
+         shared.JS.escape_for_js_string(remote_package_name))
   metadata['remote_package_size'] = remote_package_size
   metadata['package_uuid'] = str(package_uuid)
   ret += '''
@@ -744,7 +723,9 @@ if has_preloaded:
       %s
     };
     Module['addRunDependency']('datafile_%s');
-  ''' % (use_data, shared.JS.escape_for_js_string(data_target)) # use basename because from the browser's point of view, we need to find the datafile in the same dir as the html file
+  ''' % (use_data, shared.JS.escape_for_js_string(data_target))
+  # use basename because from the browser's point of view,
+  # we need to find the datafile in the same dir as the html file
 
   code += r'''
     if (!Module.preloadResults) Module.preloadResults = {};
@@ -768,7 +749,7 @@ if has_preloaded:
                 fetchCachedPackage(db, PACKAGE_PATH + PACKAGE_NAME, processPackageData, preloadFallback);
               } else {
                 console.info('loading ' + PACKAGE_NAME + ' from remote');
-                fetchRemotePackage(REMOTE_PACKAGE_NAME, REMOTE_PACKAGE_SIZE, 
+                fetchRemotePackage(REMOTE_PACKAGE_NAME, REMOTE_PACKAGE_SIZE,
                   function(packageData) {
                     cacheRemotePackage(db, PACKAGE_PATH + PACKAGE_NAME, packageData, {uuid:PACKAGE_UUID}, processPackageData,
                       function(error) {
@@ -786,8 +767,10 @@ if has_preloaded:
       if (Module['setStatus']) Module['setStatus']('Downloading...');
     '''
   else:
-    # Not using preload cache, so we might as well start the xhr ASAP, potentially before JS parsing of the main codebase if it's after us.
-    # Only tricky bit is the fetch is async, but also when runWithFS is called is async, so we handle both orderings.
+    # Not using preload cache, so we might as well start the xhr ASAP,
+    # potentially before JS parsing of the main codebase if it's after us.
+    # Only tricky bit is the fetch is async, but also when runWithFS is called
+    # is async, so we handle both orderings.
     ret += r'''
       var fetchedCallback = null;
       var fetched = Module['getPreloadedPackage'] ? Module['getPreloadedPackage'](REMOTE_PACKAGE_NAME, REMOTE_PACKAGE_SIZE) : null;
@@ -826,47 +809,51 @@ ret += '''
   }
 '''
 
-if crunch:
-  ret += '''
-  if (!Module['postRun']) Module['postRun'] = [];
-  Module["postRun"].push(function() {
-    decrunchWorker.terminate();
-  });
-'''
-
-ret += '''%s
-})();
-''' % ('''
+if separate_metadata:
+    _metadata_template = '''
   Module['removeRunDependency']('%(metadata_file)s');
  }
 
- var REMOTE_METADATA_NAME = typeof Module['locateFile'] === 'function' ?
-                            Module['locateFile']('%(metadata_file)s') :
-                            ((Module['filePackagePrefixURL'] || '') + '%(metadata_file)s');
- var xhr = new XMLHttpRequest();
- xhr.onreadystatechange = function() {
-  if (xhr.readyState === 4 && xhr.status === 200) {
-    loadPackage(JSON.parse(xhr.responseText));
-  }
- }
- xhr.open('GET', REMOTE_METADATA_NAME, true);
- xhr.overrideMimeType('application/json');
- xhr.send(null);
-
- if (!Module['preRun']) Module['preRun'] = [];
- Module["preRun"].push(function() {
+ function runMetaWithFS() {
   Module['addRunDependency']('%(metadata_file)s');
- });
-''' % {'metadata_file': os.path.basename(jsoutput + '.metadata')} if separate_metadata else '''
+  var REMOTE_METADATA_NAME = Module['locateFile'] ? Module['locateFile']('%(metadata_file)s', '') : '%(metadata_file)s';
+  var xhr = new XMLHttpRequest();
+  xhr.onreadystatechange = function() {
+   if (xhr.readyState === 4 && xhr.status === 200) {
+     loadPackage(JSON.parse(xhr.responseText));
+   }
+  }
+  xhr.open('GET', REMOTE_METADATA_NAME, true);
+  xhr.overrideMimeType('application/json');
+  xhr.send(null);
+ }
+
+ if (Module['calledRun']) {
+  runMetaWithFS();
+ } else {
+  if (!Module['preRun']) Module['preRun'] = [];
+  Module["preRun"].push(runMetaWithFS);
+ }
+''' % {'metadata_file': os.path.basename(jsoutput + '.metadata')}
+
+else:
+    _metadata_template = '''
  }
  loadPackage(%s);
-''' % json.dumps(metadata))
+''' % json.dumps(metadata)
 
-if force or len(data_files) > 0:
-  if jsoutput == None:
+ret += '''%s
+})();
+''' % _metadata_template
+
+
+if force or len(data_files):
+  if jsoutput is None:
     print(ret)
   else:
-    # Overwrite the old jsoutput file (if exists) only when its content differs from the current generated one, otherwise leave the file untouched preserving its old timestamp
+    # Overwrite the old jsoutput file (if exists) only when its content
+    # differs from the current generated one, otherwise leave the file
+    # untouched preserving its old timestamp
     if os.path.isfile(jsoutput):
       f = open(jsoutput, 'r+')
       old = f.read()
