@@ -1,10 +1,14 @@
+# Copyright 2013 The Emscripten Authors.  All rights reserved.
+# Emscripten is available under two separate licenses, the MIT license and the
+# University of Illinois/NCSA Open Source License.  Both these licenses can be
+# found in the LICENSE file.
+
 from .toolchain_profiler import ToolchainProfiler
 import time, os, sys, logging
 from subprocess import Popen, PIPE, STDOUT
 
 TRACK_PROCESS_SPAWNS = int(os.getenv('EM_BUILD_VERBOSE', '0')) >= 3
 WORKING_ENGINES = {} # Holds all configured engines and whether they work: maps path -> True/False
-__rootpath__ = os.path.dirname(os.path.dirname(__file__))
 
 def timeout_run(proc, timeout=None, note='unnamed process', full_output=False, note_args=[], throw_on_failure=True):
   start = time.time()
@@ -22,6 +26,7 @@ def timeout_run(proc, timeout=None, note='unnamed process', full_output=False, n
     logging.info('Process ' + str(proc.pid) + ' finished after ' + str(time.time() - start) + ' seconds. Exit code: ' + str(proc.returncode))
   return '\n'.join(out) if full_output else out[0]
 
+
 def make_command(filename, engine=None, args=[]):
   if type(engine) is not list:
     engine = [engine]
@@ -54,7 +59,7 @@ def check_engine(engine):
     return WORKING_ENGINES[engine_path]
   try:
     logging.debug('Checking JS engine %s' % engine)
-    if 'hello, world!' in run_js(os.path.join(__rootpath__, 'src', 'hello_world.js'), engine, skip_check=True):
+    if 'hello, world!' in run_js(shared.path_from_root('src', 'hello_world.js'), engine):
       WORKING_ENGINES[engine_path] = True
   except Exception as e:
     logging.info('Checking JS engine %s failed. Check your config file. Details: %s' % (str(engine), str(e)))
@@ -71,8 +76,23 @@ def require_engine(engine):
     sys.exit(1)
 
 
+def run_js_tool(filename, engine, jsargs=[], *args, **kw):
+  """Execute a javascript tool.
+
+  This is used by emcc to run parts of the build process that are written
+  implemented in javascript.
+  """
+  command = make_command(filename, engine, jsargs)
+  return shared.check_call(command, *args, **kw).stdout
+
+
+# TODO(sbc): Move to into test directory
 def run_js(filename, engine=None, args=[], check_timeout=False, stdin=None, stdout=PIPE, stderr=None, cwd=None,
            full_output=False, assert_returncode=0, error_limit=-1, skip_check=False):
+  """Execute javascript code generated by tests, with possible timeout."""
+  if not os.path.exists(filename):
+    raise Exception('JavaScript file not found: ' + filename)
+
   #  # code to serialize out the test suite files
   #  # XXX make sure to disable memory init files, and clear out the base_dir. you may also need to manually grab e.g. paper.pdf.js from a run of test_poppler
   #  import shutil, json
@@ -94,7 +114,6 @@ def run_js(filename, engine=None, args=[], check_timeout=False, stdin=None, stdo
 
   command = make_command(filename, engine, args)
   try:
-    if cwd is not None: os.environ['EMCC_BUILD_DIR'] = os.getcwd()
     proc = Popen(
         command,
         stdin=stdin,
@@ -109,8 +128,6 @@ def run_js(filename, engine=None, args=[], check_timeout=False, stdin=None, stdo
       require_engine(engine)
     # if we got here, then require_engine succeeded, so we can raise the original error
     raise e
-  finally:
-    if cwd is not None: del os.environ['EMCC_BUILD_DIR']
   timeout = 15*60 if check_timeout else None
   if TRACK_PROCESS_SPAWNS:
     logging.info('Blocking on process ' + str(proc.pid) + ': ' + str(command) + (' for ' + str(timeout) + ' seconds' if timeout else ' until it finishes.'))
@@ -127,7 +144,14 @@ def run_js(filename, engine=None, args=[], check_timeout=False, stdin=None, stdo
     if not skip_check:
       require_engine(engine)
     # if we got here, then require_engine succeeded, so we can raise the original error
-    raise e
+    raise
   if assert_returncode is not None and proc.returncode is not assert_returncode:
     raise Exception('Expected the command ' + str(command) + ' to finish with return code ' + str(assert_returncode) + ', but it returned with code ' + str(proc.returncode) + ' instead! Output: ' + str(ret)[:error_limit])
   return ret
+
+
+try:
+  from . import shared
+except ImportError:
+  # Python 2 circular import compatibility
+  import shared
